<?php

namespace Litecms\Test\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Test\Models\Test;

class TestPolicy
{

    /**
     * Determine if the given user can view the test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function view(UserPolicy $user, Test $test)
    {
        if ($user->canDo('test.test.view') && $user->isAdmin()) {
            return true;
        }

        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can create a test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('test.test.create');
    }

    /**
     * Determine if the given user can update the given test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function update(UserPolicy $user, Test $test)
    {
        if ($user->canDo('test.test.edit') && $user->isAdmin()) {
            return true;
        }

        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Test $test)
    {
        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Test $test)
    {
        if ($user->canDo('test.test.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given test.
     *
     * @param UserPolicy $user
     * @param Test $test
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Test $test)
    {
        if ($user->canDo('test.test.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
